@@ -28,60 +28,60 @@ pub fn from_slice<'a, T: ::serde::de::Deserialize<'a>>(buf: &'a [u8]) -> Result<
     Ok(value)
 }
 
-pub trait Deserializable {
+pub trait DeserializeFromSlice {
     fn from_slice(&mut self, buf: &[u8]) -> Result<usize, Error>;
 }
 
-impl Deserializable for Option<u8> {
+impl DeserializeFromSlice for Option<u8> {
     fn from_slice(&mut self, buf: &[u8]) -> Result<usize, Error> {
         let (v, n) = read_u8(buf)?;
         *self = Some(v);
         Ok(n)
     }
 }
-impl Deserializable for Option<u16> {
+impl DeserializeFromSlice for Option<u16> {
     fn from_slice(&mut self, buf: &[u8]) -> Result<usize, Error> {
         let (v, n) = read_u16(buf)?;
         *self = Some(v);
         Ok(n)
     }
 }
-impl Deserializable for Option<u32> {
+impl DeserializeFromSlice for Option<u32> {
     fn from_slice(&mut self, buf: &[u8]) -> Result<usize, Error> {
         let (v, n) = read_u32(buf)?;
         *self = Some(v);
         Ok(n)
     }
 }
-impl Deserializable for Option<u64> {
+impl DeserializeFromSlice for Option<u64> {
     fn from_slice(&mut self, buf: &[u8]) -> Result<usize, Error> {
         let (v, n) = read_u64(buf)?;
         *self = Some(v);
         Ok(n)
     }
 }
-impl Deserializable for Option<i8> {
+impl DeserializeFromSlice for Option<i8> {
     fn from_slice(&mut self, buf: &[u8]) -> Result<usize, Error> {
         let (v, n) = read_i8(buf)?;
         *self = Some(v);
         Ok(n)
     }
 }
-impl Deserializable for Option<i16> {
+impl DeserializeFromSlice for Option<i16> {
     fn from_slice(&mut self, buf: &[u8]) -> Result<usize, Error> {
         let (v, n) = read_i16(buf)?;
         *self = Some(v);
         Ok(n)
     }
 }
-impl Deserializable for Option<i32> {
+impl DeserializeFromSlice for Option<i32> {
     fn from_slice(&mut self, buf: &[u8]) -> Result<usize, Error> {
         let (v, n) = read_i32(buf)?;
         *self = Some(v);
         Ok(n)
     }
 }
-impl Deserializable for Option<i64> {
+impl DeserializeFromSlice for Option<i64> {
     fn from_slice(&mut self, buf: &[u8]) -> Result<usize, Error> {
         let (v, n) = read_i64(buf)?;
         *self = Some(v);
@@ -270,21 +270,21 @@ pub fn read_i64<B: ByteSlice>(buf: B) -> Result<(i64, usize), Error> {
         }
         Marker::I8 => {
             if buf.len() >= 2 {
-                Ok((buf[1] as i64, 2))
+                Ok((buf[1] as i8 as i64, 2))
             } else {
                 Err(Error::EndOfBuffer)
             }
         }
         Marker::I16 => {
             if buf.len() >= 3 {
-                Ok((BigEndian::read_i16(&buf[1..3]) as i64, 3))
+                Ok((BigEndian::read_i16(&buf[1..3]) as i16 as i64, 3))
             } else {
                 Err(Error::EndOfBuffer)
             }
         }
         Marker::I32 => {
             if buf.len() >= 5 {
-                Ok((BigEndian::read_i32(&buf[1..5]) as i64, 5))
+                Ok((BigEndian::read_i32(&buf[1..5]) as i32 as i64, 5))
             } else {
                 Err(Error::EndOfBuffer)
             }
