@@ -9,7 +9,7 @@ mod seq;
 mod struct_;
 
 use super::Error;
-use crate::encode::Serializable;
+use crate::encode::SerializeIntoSlice;
 
 pub(crate) struct Serializer<'a> {
     buf: &'a mut [u8],
@@ -18,7 +18,7 @@ pub(crate) struct Serializer<'a> {
 
 impl<'a> Serializer<'a> {
     fn new(buf: &'a mut [u8]) -> Self { Serializer { buf, pos: 0 } }
-    fn append<S: Serializable>(&mut self, value: S) -> Result<(), Error> {
+    fn append<S: SerializeIntoSlice>(&mut self, value: S) -> Result<(), Error> {
         self.pos += value.write_into_slice(&mut self.buf[self.pos..])?;
         Ok(())
     }
@@ -92,9 +92,9 @@ impl<'a, 'b> ser::Serializer for &'a mut Serializer<'b> {
         self.serialize_str(variant)
     }
 
-    fn serialize_newtype_struct<T: ?Sized>(self, _name: &'static str, _value: &T) -> Result<Self::Ok, Self::Error>
+    fn serialize_newtype_struct<T: ?Sized + ::serde::Serialize>(self, _name: &'static str, v: &T) -> Result<Self::Ok, Self::Error>
     where T: ser::Serialize {
-        unreachable!()
+        v.serialize(self)
     }
 
     fn serialize_newtype_variant<T: ?Sized>(
